==> 4.4.3.tar.gz: terraform-provider-decort/internal/service/cloudbroker/vins/utility_vins.go <==
/*
Copyright (c) 2019-2022 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package vins

import (
	"context"
	"fmt"
	"strconv"

	log "github.com/sirupsen/logrus"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudbroker/vins"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"

	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
)

func utilityVinsCheckPresence(ctx context.Context, d *schema.ResourceData, m interface{}) (*vins.RecordVINS, error) {
	c := m.(*controller.ControllerCfg)

	idSet := false
	vinsID, err := strconv.ParseUint(d.Id(), 10, 64)
	if err != nil || vinsID <= 0 {
		vinsId, argSet := d.GetOk("vins_id") // NB: vins_id is NOT present in vinsResource schema!
		if argSet {
			vinsID = uint64(vinsId.(int))
			idSet = true
		}
	} else {
		idSet = true
	}

	if idSet {
		log.Debugf("utilityVinsCheckPresence: locating ViNS by its ID %d", vinsID)
		req := vins.GetRequest{VINSID: vinsID}

		vinsFacts, err := c.CloudBroker().VINS().Get(ctx, req)
		if err != nil {
			return nil, err
		}

		return vinsFacts, nil
	}

	vinsName, argSet := d.GetOk("name")
	if !argSet {
		return nil, fmt.Errorf("Cannot check ViNS presence if ViNS name is empty")
	}
	req := vins.SearchRequest{
		Name:    vinsName.(string),
		ShowAll: false,
	}
	log.Debugf("utilityVinsCheckPresence: preparing to locate ViNS name %s", vinsName.(string))

	rgId, rgSet := d.GetOk("rg_id")
	if rgSet {
		log.Debugf("utilityVinsCheckPresence: limiting ViNS search to RG ID %d", rgId.(int))
		req.RGID = uint64(rgId.(int))
	}

	accountId, accountSet := d.GetOk("account_id")
	if accountSet {
		log.Debugf("utilityVinsCheckPresence: limiting ViNS search to Account ID %d", accountId.(int))
		req.AccountID = uint64(accountId.(int))
	}

	vinsList, err := c.CloudBroker().VINS().Search(ctx, req)
	if err != nil {
		return nil, err
	}

	log.Debugf("utilityVinsCheckPresence: traversing decoded Json of length %d", len(vinsList))
	for index, item := range vinsList {
		if item.Name == vinsName.(string) {
			if (accountSet && item.AccountID != uint64(accountId.(int))) ||
				(rgSet && item.RGID != uint64(rgId.(int))) {
				continue
			}

			log.Debugf("utilityVinsCheckPresence: match ViNS name %s / ID %d, account ID %d, RG ID %d at index %d",
				item.Name, item.ID, item.AccountID, item.RGID, index)

			req := vins.GetRequest{VINSID: item.ID}

			vinsGetResp, err := c.CloudBroker().VINS().Get(ctx, req)
			if err != nil {
				return nil, err
			}

			return vinsGetResp, nil
		}
	}

	return nil, fmt.Errorf("Cannot find ViNS name %s. Check name and/or RG ID & Account ID and your access rights", vinsName.(string))
}

==> 4.7.4.tar.gz: terraform-provider-decort/internal/service/cloudbroker/vins/utility_vins.go <==
/*
Copyright (c) 2019-2023 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Sergey Kisil, <svkisil@digitalenergy.online>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package vins

import (
	"context"
	"strconv"

	log "github.com/sirupsen/logrus"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudbroker/vins"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"

	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
)

func utilityVinsCheckPresence(ctx context.Context, d *schema.ResourceData, m interface{}) (*vins.RecordVINS, error) {
	c := m.(*controller.ControllerCfg)

	log.Debug("utilityVinsCheckPresence: locating ViNS by its ID")
	req := vins.GetRequest{}

	if d.Id() != "" {
		id, _ := strconv.ParseUint(d.Id(), 10, 64)
		req.VINSID = id
	} else {
		req.VINSID = uint64(d.Get("vins_id").(int))
	}

	vins, err := c.CloudBroker().VINS().Get(ctx, req)
	if err != nil {
		return nil, err
	}

	return vins, nil
}
